system.SiteConfigs (Site configurations) — amici1

# `system.SiteConfigs` (Site configurations)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<lino.core.choicelists.ChoiceListField: default_build_method>`

- `<django.db.models.fields.DateField: simulate_today>`

- `<django.db.models.fields.related.ForeignKey: site_company>`

- `<django.db.models.fields.IntegerField: next_partner_id>`

- `<django.db.models.fields.related.ForeignKey: default_event_type>`

- `<django.db.models.fields.related.ForeignKey: site_calendar>`

- `<django.db.models.fields.IntegerField: max_auto_events>`

- `<django.db.models.fields.DateField: hide_events_before>`

- `<django.db.models.fields.related.ForeignKey: pupil_guestrole>`

Detail fields

- `<Panel main_1 in lino.core.layouts.DetailLayout on lino.modlib.system.models.SiteConfigs>`

- `<Panel main_2 in lino.core.layouts.DetailLayout on lino.modlib.system.models.SiteConfigs>`

- `<Panel main_3 in lino.core.layouts.DetailLayout on lino.modlib.system.models.SiteConfigs>`

- `<Panel main_4 in lino.core.layouts.DetailLayout on lino.modlib.system.models.SiteConfigs>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Rebuild site cache (do_build) : Rebuild the site cache. This action is available on About.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

## Filter parameters